@@ -11,7 +11,9 @@ __PACKAGE__->add_columns(
   { data_type => "inet", is_nullable => 0 },
   "snmp_comm_rw",
   { data_type => "text", is_nullable => 1 },
-  "snmp_auth_tag",
+  "snmp_auth_tag_read",
+  { data_type => "text", is_nullable => 1 },
+  "snmp_auth_tag_write",
   { data_type => "text", is_nullable => 1 },
 );
 __PACKAGE__->set_primary_key("ip");
